\n
\n\n\n\n
\n\n\n\n\n\n
\n\n\n
\n
\n
\n
\n
\n\n\n\n
\n
\n
\n
\n
\n
\n
\n

\n

- Photo may represent series and not specific product

\n
- SHARE
\n
\n
\n
\n
\n
\n

\n
\n
\n\n
\n

## Rotax 912 iS Fuel Pump Assembly Cover

\n
\n
\n0 Reviews 0 Answered Questions\n
\n
From $0.90 to $7.87
\n
\n

\n
- SHARE
\n
\n
\n
\n
\n
\n

\n
\n
\n
\n
\n
\n

(Hover to zoom | Use mouse wheel for +/-)

\n
\n
\n
\n
\n
\n
\n
\n

\n
\n
\nNo.\n | Rotax Part Number\n | Description\n | Qty Req\n | PN\n | Price\n | Buy\n
--- | --- | --- | --- | --- | --- | ---
\n
\n
\n
\n5 | 926-274 | WASHER 8.2/12.5/1.5 | 1 | 15-02979 | $7.87 | \n Quantity \n\n
\n
\n15 | 241-482 | ALLEN SCREW M6X90 | 2 | 15-00180 | $1.49 | \n Quantity \n\n
\n
\n16 | 241-814 | ALLEN SCREW M6X35 | 2 | 15-00187 | $1.22 | \n Quantity \n\n
\n
\n18 | 241-813 | ALLEN SCREW M6X35, STAINLESS | 1 | 15-00188 | $0.90 | \n Quantity \n\n
\n
\n

\n
\n
\n
\n
\n
\n
\n
\n
\n
Subtotal $0.00
\nAdd to Wishlist\n
\n
\n
\n
\n
\n
\n\n
\nJUMP TO\n

\n
- JUMP TO
\n
- Overview
\n
- Reviews
\n
- Q&A
\n
\n

\n
\n\n
\n
\n\n
\n
\n

## Overview

\n

\n
\n\nRotax 912iS Water Pump with Drive. \r\nExplanations of symbols and statements in part number charts: \r\n N = Newly introduced part number\r\n s.v. = Still valid. Part was replaced by compatible component and can not be supplied any longer by the producer. Existing stock may be used.\r\n AR = As required. This generally refers to shims, hose, wires, and cable. Measure the amount you need before ordering. Many times there will be multiple listings of different lengths with the same part number. Use individual part descriptions to determine the proper length needed.\r\n n.a or NLA = No longer available, no replacement from Rotax. Part is no longer available due to incompatibility to current production or unavailability of part.\r\n CALL = Please call for price, 800-247-9653 \r\n \n
\n

\n
\n
\n \n | \n
\n
\n\n | WARNING: Cancer and Reproductive Harm - www.P65Warnings.ca.gov. \n
\n
\n

\n
\n
\n\n
\n
\n
\n

\n
- Frequently Purchased With
- Customers Also Viewed

\n
\n
\n
\n
\n
\n\n
\n
\n\n
\n
\n
$0.00
\n
\n
\nQuick Shop\n
\n
\n
\n
\n
\n\n
\n
\nRotax Oil Filter 825-016\n
\n
\n
$48.75
\n
\n
\nQuick Shop\n
\n
\n
\n
\n
\n\n
\n
\nNGK Spark Plug DCPR7E - Removable Nut\n
\n
\n
$4.95
\n
\n
\nQuick Shop\n
\n
\n
\n
\n
\n\n
\n
\nROTAX ALLEN SCREW M6X90 241482\n
\n
\n
$1.49
\n
\n
\nQuick Shop\n
\n
\n
\n
\n
\n\n
\n
\nRotax Allen Screw M6X35 241811\n
\n
\n
$1.22
\n
\n
\nQuick Shop\n
\n
\n
\n
\n
\n\n
\n
\n\n
\n
\n
$0.00
\n
\n
\nQuick Shop\n
\n
\n
\n
\n
\n\n
\n
\n\n
\n
\n
$0.00
\n
\n
\nQuick Shop\n
\n
\n
\n
\n
\n
\n
\n\n
\n
\nRotax 912 | 914 Ul Water Pump With Drive\n
\n
\n
$12.50
\n
\n
\nQuick Shop\n
\n
\n
\n
\n
\n\n
\n
\nRotax Oil Filter 825-016\n
\n
\n
$48.75
\n
\n
\nQuick Shop\n
\n
\n
\n
\n
\n\n
\n
\nRotax 912 | 914 Ul Oil Pump Assembly | Oil Filter | Oil Temperature Sensor | Oil Pressure Sensor\n
\n
\n
$9.05
\n
\n
\nQuick Shop\n
\n
\n
\n
\n
\n\n
\n
\nRotax 912 iS Oil Pump Assembly | Oil Filter | Oil Temperature Sensor | Oil Pressure Sensor Parts\n
\n
\n
$0.00
\n
\n
\nQuick Shop\n
\n
\n
\n
\n
\n\n
\n
\nRotax 915 iS Oil Pump Assembly | Oil Filter | Oil Temperature Sensor | Oil Pressure Sensor Parts\n
\n
\n
$0.72
\n
\n
\nQuick Shop\n
\n
\n
\n
\n
\n\n
\n
\nRotax 915 iS Water Pump With Drive\n
\n
\n
$0.90
\n
\n
\nQuick Shop\n
\n
\n
\n
\n
\n\n
\n
\nRotax 912 | 914 Ul Oil Tank Parts\n
\n
\n
$89.75
\n
\n
\nQuick Shop\n
\n
\n
\n
\n
\n\n
\n
\nRotax Carburetor - Single Parts 912 Series\n
\n
\n
$0.00
\n
\n
\nQuick Shop\n
\n
\n
\n
\n
\n\n
\n
\nRotax 915 iS Oil Tank Parts\n
\n
\n
$7.00
\n
\n
\nQuick Shop\n
\n
\n
\n
\n
\n\n
\n
\nRotax 912 | 914 Ul Propeller Gear Assembly\n
\n
\n
$0.00
\n
\n
\nQuick Shop\n
\n
\n
\n
\n
\n\n
\n
\n912 iS Repair Tools (Non Certified)\n
\n
\n
$0.00
\n
\n
\nQuick Shop\n
\n
\n
\n
\n
\n
\n
\n\n
\n
\n

## Reviews

\n
\n
\nSubmit a Review\n
\n
\n
\n
\n
\n\n\n
\n
\n

## Q&A

\n
\n \n\nSubmit\n \n
\n

Please note, Aircraft Spruce's personnel are not certified aircraft mechanics and can only provide general support and ideas, which should not be relied upon or implemented in lieu of consulting an A&P or other qualified technician. Aircraft Spruce assumes no responsibility or liability for any issue or problem which may arise from any repair, modification or other work done from this knowledge base. Any product eligibility information provided here is based on general application guides and we recommend always referring to your specific aircraft parts manual, the parts manufacturer or consulting with a qualified mechanic.

\n
\n
\n
\n
\n
\n \n

\n
\nQuestion About:\n | Rotax 912 iS Fuel Pump Assembly Cover\n
\n
\nEmail:\n | \n\n
\n
\nYour Name:\n | \n\n
\n
\nQuestion:\n | \n\n\n
\n
\n\n | \n \n\n
\n
\n\n | \nSubmit\n\n
\n

\n \n
\n
\n \n

\n
\nReview Product:\n | Rotax 912 iS Fuel Pump Assembly Cover\n
\n
\nEmail:\n | \n\n
\n
\nYour Name:\n | \n\n
\n
\nRating:\n | \n \n\n
\n
\nComments:\n | \n\n\n
\n
\n\n | \n \n\n
\n
\n\n | \nSubmit\n\n
\n

\n \n
\n\n\n
\n\n\n
\n